To do list
==========

- a class using 2decomp&FFT http://www.2decomp.org ?
- perfect the cpp classes,
- perfect the Python-Cython side,
- improve build-install which has to depend on which libraries are available,
- benches on different types of clusters (legi, ciment, idris?)
- decent documentation
- make fluidsim running with fluidfft to show that it is functional


Inline to do items
------------------

.. todolist::


